==> haskell-memotrie-0.6.10-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MemoTrie
version:              0.6.10
visibility:           public
id:                   MemoTrie-0.6.10-1zujH8DtPLgFPC9Hb5N1xE
key:                  MemoTrie-0.6.10-1zujH8DtPLgFPC9Hb5N1xE
license:              BSD-3-Clause
copyright:            (c) 2008-2019 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
homepage:             https://github.com/conal/MemoTrie
synopsis:             Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.

    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>

    &#199; 2008-2019 by Conal Elliott; BSD3 license.

category:             Data
abi:                  d398266dec94a0b56258bfa9613c526f
exposed:              True
exposed-modules:      Data.MemoTrie
import-dirs:          /usr/lib/ghc-8.10.2/site-local/MemoTrie-0.6.10
library-dirs:         /usr/lib/ghc-8.10.2/site-local/MemoTrie-0.6.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/MemoTrie-0.6.10
hs-libraries:         HSMemoTrie-0.6.10-1zujH8DtPLgFPC9Hb5N1xE
depends:
    base-4.14.1.0 newtype-generics-0.5.4-JMDq2f2QiFh7dkmNLx7KtR

haddock-interfaces:   /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html:         /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-memotrie-0.6.10-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MemoTrie
version:              0.6.10
visibility:           public
id:                   MemoTrie-0.6.10-4ynT7O34ZoLiunXlSP2tV
key:                  MemoTrie-0.6.10-4ynT7O34ZoLiunXlSP2tV
license:              BSD-3-Clause
copyright:            (c) 2008-2019 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
homepage:             https://github.com/conal/MemoTrie
synopsis:             Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.

    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>

    &#199; 2008-2019 by Conal Elliott; BSD3 license.

category:             Data
abi:                  a601a9c2f2566c2bb831af64b83c2617
exposed:              True
exposed-modules:      Data.MemoTrie
import-dirs:          /usr/lib/ghc-8.10.2/site-local/MemoTrie-0.6.10
library-dirs:         /usr/lib/ghc-8.10.2/site-local/MemoTrie-0.6.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/MemoTrie-0.6.10
hs-libraries:         HSMemoTrie-0.6.10-4ynT7O34ZoLiunXlSP2tV
depends:
    base-4.14.1.0 newtype-generics-0.5.4-Eea1NCEMOVQLmN0AJP3wdJ

haddock-interfaces:   /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html:         /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
